Allele mutation probability computation
gka_allele_mutation(data, k, centers, ...)a matrix of size n by k with the probability of each
allele mutating to a specific cluster.
a set of observations, presented as a matrix-like object where
every row is a new observation. The matrix is of size n by m.
the number of clusters.
a matrix of size k by m with the cluster centers
additional arguments passed to proxy::dist().
Eduardo Ruiz Sabajanes, eduardo.ruizs@edu.uah.es