Total Within Cluster Variation (TWCV) computation
gka_twcv(data, k, population, centers)a vector of size p with the total within cluster variation of
each individual in the population.
a set of observations, presented as a matrix-like object where
every row is a new observation. The matrix is of size n by m.
the number of clusters.
a matrix of size p by n with the cluster
assignments for each observation.
a 3D array of size p by k by m with the
cluster centers for each individual in the population.
Eduardo Ruiz Sabajanes, eduardo.ruizs@edu.uah.es